@@ -1,13 +1,14 @@
 #' Fetch a list of nodes
 #'
-#' @usage node()
+#' @usage node(verbose = FALSE)
+#' @param verbose logical. Optional parameter to enable verbose logging (default = \code{FALSE}).
 #' @return The nodes
 #' @examples
 #' nodes <- node()
 #' @export
-node <- function() {
-  result <- http_request("GET", "node", NULL)
-  stop_for_status(result)
+node <- function(verbose = FALSE) {
+  result <- http_request("GET", "node", NULL, verbose)
+  if (is.null(result)) return(invisible(NULL))
   text <- content(result, "text", encoding = "UTF-8")
   res <- fromJSON(text, simplifyVector = TRUE)
   total <- res$total
